import { useMemo, useRef } from 'react';
import { useFirestoreDoc, useFirestoreDocOnce } from 'reactfire';
import { useDocumentSnapData } from './useSnapData.js';
import { useFirestoreErrorLogger, useSafeRef } from './utils.js';
const createUseTypedDocHook = (hook) => {
    return (typedRef, dataOptions = {}) => {
        const { safeRef, refChanged } = useSafeRef(typedRef.raw);
        const memoizedTypedRef = useRef();
        if (refChanged) {
            memoizedTypedRef.current = typedRef;
        }
        const { data: _snap, error } = hook(safeRef, { suspense: true });
        useFirestoreErrorLogger(error);
        const { snap, data } = useDocumentSnapData(typedRef, _snap, dataOptions);
        return useMemo(() => {
            refChanged;
            return { typedRef: memoizedTypedRef.current, snap, data, error };
        }, [data, error, refChanged, snap]);
    };
};
export const useTypedDoc = createUseTypedDocHook(useFirestoreDoc);
export const useTypedDocOnce = createUseTypedDocHook(useFirestoreDocOnce);
